@@ -45,8 +45,10 @@
 #include "dbus/dbus.h"
 
 #include "localisation.h"
+#include "settings.h"
+#include "filters.h"
+
 
-#define DEFAULT_LIMIT 30
 
 static void
 get_time_string (
@@ -280,150 +282,107 @@ static void button_clicked (GtkButton* button, gpointer data)
     gtk_main_quit();
 }
 
-static gboolean set_limit(gint limit)
+
+
+
+
+
+static void call_type_dialog(GtkButton* button, gpointer data)
 {
-	/* Get the default client */
-	GConfClient *client = gconf_client_get_default();
+    GtkWidget *dialog;
+    GtkWidget *box;
 
-	gconf_client_add_dir (client, "/apps/extcalllog",
-	                GCONF_CLIENT_PRELOAD_NONE, NULL);
+    GtkWidget *all_button;
+    GtkWidget *voip_button;
+    GtkWidget *gsm_button;
 
-	if(limit < -1 || limit == 0)
-		limit = DEFAULT_LIMIT;
+    AppData *appdata = data;
 
-	return gconf_client_set_int (client,
-			"/apps/extcalllog/limit",
-            limit,
-            NULL);
-}
 
-static gint get_limit()
-{
-	gint limit;
-	/* Get the default client */
-	GConfClient *client = gconf_client_get_default();
 
-	/*Add GConf node if absent*/
-	/*if(!gconf_client_dir_exists(client, GCONF_NODE, NULL))
-	{*/
-	gconf_client_add_dir (client, "/apps/extcalllog",
-	                GCONF_CLIENT_PRELOAD_NONE, NULL);
+    dialog = gtk_dialog_new_with_buttons("Call Type",
+			appdata->mainWindow,
+			GTK_DIALOG_MODAL,
+			GTK_STOCK_OK,
+			GTK_RESPONSE_OK,
+			NULL);
 
-	limit = gconf_client_get_int(client,"/apps/extcalllog/limit", NULL);
+    box = GTK_DIALOG(dialog)->vbox;
 
-	if(limit < -1 || limit == 0)
-	{
-		limit = DEFAULT_LIMIT;
-		set_limit(limit);
-	}
+    all_button = hildon_gtk_radio_button_new(HILDON_SIZE_AUTO , NULL);
+    gtk_button_set_label(GTK_BUTTON(all_button), "All Types");
+    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(all_button), FALSE);
+    hildon_gtk_widget_set_theme_size(all_button, HILDON_SIZE_FINGER_HEIGHT);
+    gtk_widget_show(all_button);
 
-	return limit;
+    g_signal_connect(
+    		G_OBJECT(all_button),
+            "clicked",
+            G_CALLBACK(all_call_types),
+            appdata);
+
+    voip_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(all_button));
+    gtk_button_set_label(GTK_BUTTON(voip_button), "VoIP");
+    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(voip_button), FALSE);
+    hildon_gtk_widget_set_theme_size(voip_button, HILDON_SIZE_FINGER_HEIGHT);
+    gtk_widget_show(voip_button);
+
+    g_signal_connect(
+        	G_OBJECT(voip_button),
+            "clicked",
+            G_CALLBACK(voip_calls),
+            appdata);
+
+    gsm_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(voip_button));
+    gtk_button_set_label(GTK_BUTTON(gsm_button), "GSM");
+    gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(gsm_button), FALSE);
+    hildon_gtk_widget_set_theme_size(gsm_button, HILDON_SIZE_FINGER_HEIGHT);
+    gtk_widget_show(gsm_button);
+
+    g_signal_connect(
+        	G_OBJECT(gsm_button),
+            "clicked",
+            G_CALLBACK(gsm_calls),
+            appdata);
+
+    switch(appdata->current_type)
+    {
+		case ALL:
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(all_button), TRUE);
+			break;
+		}
+		case VOIP:
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(voip_button), TRUE);
+			break;
+		}
+		case GSM:
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gsm_button), TRUE);
+			break;
+		}
+    }
+
+    gtk_box_pack_start (GTK_BOX (box), all_button, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (box), voip_button, FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (box), gsm_button, FALSE, FALSE, 0);
+
+
+
+    /*GtkWidget *content_area = GTK_DIALOG(dialog)->vbox;
+    GtkWidget *content_widget = settings_widget_create(GTK_WINDOW(dialog));*/
+
+    /* Add the widget to the dialog
+    gtk_box_pack_start(GTK_BOX(content_area), content_widget, TRUE, TRUE, 10);*/
+
+    /* When a button (ok/cancel/etc.) is clicked or the dialog is closed - destroy it */
+    g_signal_connect(dialog, "response", G_CALLBACK(gtk_widget_destroy), NULL);
+
+    gtk_dialog_run(GTK_DIALOG(dialog));
 
 }
 
-
-
-static void missed_calls (GtkButton* button, gpointer data)
-{
-    g_debug("missed calls...");
-	RTComLogModel * model = NULL;
-    model = RTCOM_LOG_MODEL(data);
-    RTComElQuery *query = NULL;
-    RTComEl * eventlogger = NULL;
-    eventlogger = rtcom_log_model_get_eventlogger(model);
-    query = rtcom_el_query_new(eventlogger);
-    rtcom_el_query_prepare(query,
-    		"service", "RTCOM_EL_SERVICE_CALL", RTCOM_EL_OP_EQUAL,
-    		"event-type", "RTCOM_EL_EVENTTYPE_CALL_MISSED", RTCOM_EL_OP_EQUAL,
-    		NULL);
-
-    rtcom_log_model_populate_query(model, query);
-    g_object_unref(query);
-}
-
-static void recieved_calls (GtkButton* button, gpointer data)
-{
-    g_debug("recieved calls...");
-	RTComLogModel * model = NULL;
-    model = RTCOM_LOG_MODEL(data);
-    RTComElQuery *query = NULL;
-    RTComEl * eventlogger = NULL;
-    eventlogger = rtcom_log_model_get_eventlogger(model);
-    query = rtcom_el_query_new(eventlogger);
-    rtcom_el_query_prepare(query,
-    		"service", "RTCOM_EL_SERVICE_CALL", RTCOM_EL_OP_EQUAL,
-    		"event-type", "RTCOM_EL_EVENTTYPE_CALL_INBOUND", RTCOM_EL_OP_EQUAL,
-    		NULL);
-
-    rtcom_log_model_populate_query(model, query);
-    g_object_unref(query);
-}
-
-static void dialed_calls (GtkButton* button, gpointer data)
-{
-    g_debug("dialed calls...");
-    RTComLogModel * model = NULL;
-    model = RTCOM_LOG_MODEL(data);
-    RTComElQuery *query = NULL;
-    RTComEl * eventlogger = NULL;
-    eventlogger = rtcom_log_model_get_eventlogger(model);
-    query = rtcom_el_query_new(eventlogger);
-    rtcom_el_query_prepare(query,
-    		"service", "RTCOM_EL_SERVICE_CALL", RTCOM_EL_OP_EQUAL,
-    		"event-type", "RTCOM_EL_EVENTTYPE_CALL_OUTBOUND", RTCOM_EL_OP_EQUAL,
-    		NULL);
-
-    rtcom_log_model_populate_query(model, query);
-    g_object_unref(query);
-}
-
-static void voip_calls (GtkButton* button, gpointer data)
-{
-    g_debug("voip calls...");
-    RTComLogModel * model = NULL;
-    model = RTCOM_LOG_MODEL(data);
-    RTComElQuery *query = NULL;
-    RTComEl * eventlogger = NULL;
-    eventlogger = rtcom_log_model_get_eventlogger(model);
-    query = rtcom_el_query_new(eventlogger);
-    rtcom_el_query_prepare(query,
-    		"service", "RTCOM_EL_SERVICE_CALL", RTCOM_EL_OP_EQUAL,
-    		"local_uid", "ring/tel/ring", RTCOM_EL_OP_NOT_EQUAL,
-    		NULL);
-
-    rtcom_log_model_populate_query(model, query);
-    g_object_unref(query);
-}
-
-static void
-populate_calls(
-        GtkWidget * widget,
-        gpointer data)
-{
-    RTComLogModel * model = NULL;
-    const gchar * services[] = {"RTCOM_EL_SERVICE_CALL", NULL};
-
-    g_debug("Populating calls...");
-
-    model = RTCOM_LOG_MODEL(data);
-    rtcom_log_model_populate(model, services);
-}
-
-static void
-refresh(
-        GtkWidget * widget,
-        gpointer data)
-{
-    RTComLogModel * model = NULL;
-
-    g_debug("Refreshing...");
-
-    model = RTCOM_LOG_MODEL(data);
-    rtcom_log_model_refresh(model);
-}
-
-
-
 void wizard_response(GtkDialog *dialog,
         gint       response_id,
         gint *response)
@@ -477,22 +436,63 @@ some_page_func (GtkNotebook *nb,
 	return TRUE;
 }
 
+void all_default (GtkButton* button, gpointer data)
+{
+	if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)))
+	{
+		return;
+	}
+	AppData* appdata = data;
+	appdata->settings.default_type = ALL;
+	set_default_type(ALL);
+}
+
+void voip_default (GtkButton* button, gpointer data)
+{
+	if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)))
+	{
+		return;
+	}
+	AppData* appdata = data;
+	appdata->settings.default_type = VOIP;
+	set_default_type(VOIP);
+}
+
+void gsm_default (GtkButton* button, gpointer data)
+{
+	if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)))
+	{
+		return;
+	}
+	AppData* appdata = data;
+	appdata->settings.default_type = GSM;
+	set_default_type(GSM);
+
+}
 create_settings_wizard(AppData *appdata)
 {
 	g_debug("creating settings...");
 	GtkWidget *wizard, *notebook;
 	GtkWidget *limit_label;
 	GtkWidget *limit_entry;
+	GtkWidget *all_button, *voip_button, *gsm_button;
 	GtkWidget *main_vbox;
+	GtkWidget *type_vbox;
+	GtkWidget *done_desc_label;
+	GtkWidget *done_label;
+	GtkWidget *type_label;
 
 	notebook = gtk_notebook_new ();
 
 	main_vbox = gtk_vbox_new(FALSE, 8);
+	type_vbox = gtk_vbox_new(FALSE, 8);
 
 
+	/*
+	 * Setup the limit page
+	 */
 	limit_label = gtk_label_new ("Limit");
 
-
 	limit_entry = hildon_entry_new (HILDON_SIZE_AUTO);
 	g_object_set (G_OBJECT (limit_entry), "hildon-input-mode", HILDON_GTK_INPUT_MODE_NUMERIC, NULL);
 	/*
@@ -510,8 +510,81 @@ create_settings_wizard(AppData *appdata)
 	gtk_box_pack_start (GTK_BOX (main_vbox), limit_label, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (main_vbox), limit_entry, FALSE, FALSE, 0);
 
+	/*
+	 * default type page
+	 */
+	type_label = gtk_label_new ("Default Call Type");
+
+	all_button = hildon_gtk_radio_button_new(HILDON_SIZE_AUTO , NULL);
+	gtk_button_set_label(GTK_BUTTON(all_button), "All Types");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(all_button), FALSE);
+	hildon_gtk_widget_set_theme_size(all_button, HILDON_SIZE_FINGER_HEIGHT);
+	gtk_widget_show(all_button);
+
+	g_signal_connect(
+	 		G_OBJECT(all_button),
+	        "clicked",
+	        G_CALLBACK(all_default),
+	        appdata);
+
+	voip_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(all_button));
+	gtk_button_set_label(GTK_BUTTON(voip_button), "VoIP");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(voip_button), FALSE);
+	hildon_gtk_widget_set_theme_size(voip_button, HILDON_SIZE_FINGER_HEIGHT);
+	gtk_widget_show(voip_button);
+
+	g_signal_connect(
+	     	G_OBJECT(voip_button),
+	        "clicked",
+	        G_CALLBACK(voip_default),
+	        appdata);
+
+	gsm_button = hildon_gtk_radio_button_new_from_widget(HILDON_SIZE_AUTO , GTK_RADIO_BUTTON(voip_button));
+	gtk_button_set_label(GTK_BUTTON(gsm_button), "GSM");
+	gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(gsm_button), FALSE);
+	hildon_gtk_widget_set_theme_size(gsm_button, HILDON_SIZE_FINGER_HEIGHT);
+	gtk_widget_show(gsm_button);
+
+    g_signal_connect(
+    		G_OBJECT(gsm_button),
+	        "clicked",
+	        G_CALLBACK(gsm_default),
+	        appdata);
+
+	switch(appdata->settings.default_type)
+	{
+		case ALL:
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(all_button), TRUE);
+			break;
+		}
+		case VOIP:
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(voip_button), TRUE);
+			break;
+		}
+		case GSM:
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gsm_button), TRUE);
+			break;
+		}
+	}
+	gtk_box_pack_start (GTK_BOX (type_vbox), all_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (type_vbox), voip_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (type_vbox), gsm_button, FALSE, FALSE, 0);
+
+
+	/*
+	 * Done page
+	 */
+	done_label = gtk_label_new("Finished");
+	done_desc_label = gtk_label_new(
+				"Your settings are now configured.");
+
 	/* Append pages */
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), main_vbox, NULL);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), type_vbox, type_label);
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), done_desc_label, done_label);
 
 	wizard = hildon_wizard_dialog_new(GTK_WINDOW(appdata->mainWindow), "Settings", GTK_NOTEBOOK(notebook));
 
@@ -537,7 +610,6 @@ settings_clicked(
         GtkWidget * widget,
         gpointer user_data)
 {
-	RTComLogModel * model = NULL;
     AppData * appdata = user_data;
 
     g_debug("Create Settings...");
@@ -568,6 +640,7 @@ int main( int argc, char* argv[] )
 	appdata.static_group_by = RTCOM_EL_QUERY_GROUP_BY_NONE;
 	appdata.showing_details = FALSE;
 
+
     osso_context_t *osso_cont;
 	osso_return_t ret;
 
@@ -579,7 +652,7 @@ int main( int argc, char* argv[] )
 	GtkWidget * recieved_button = NULL;
 	GtkWidget * missed_button = NULL;
     GtkWidget * all_button = NULL;
-    GtkWidget * voip_button = NULL;
+    GtkWidget * call_type_button = NULL;
     GtkWidget * settings_button = NULL;
     HildonAppMenu *menu;
 
@@ -605,6 +678,10 @@ int main( int argc, char* argv[] )
     }
 
     gint limit = get_limit();
+    appdata.settings.default_type = get_default_type();
+    appdata.current_type = appdata.settings.default_type;
+    appdata.current_direction = ALL_DIRECTIONS;
+
     /* Create the hildon program and setup the title */
     appdata.program = HILDON_PROGRAM(hildon_program_get_instance());
     g_set_application_name("Extended Call Log");
@@ -626,11 +703,15 @@ int main( int argc, char* argv[] )
 
     rtcom_log_model_set_group_by(appdata.log_model, appdata.static_group_by);
     eventlogger = rtcom_log_model_get_eventlogger(appdata.log_model);
+    /*
     const gchar * services[] = {"RTCOM_EL_SERVICE_CALL", NULL};
 
     g_debug("Populating calls...");
 
     rtcom_log_model_populate(appdata.log_model, services);
+    */
+    populate_calls_default(&appdata);
+
     rtcom_log_search_bar_set_model(
             RTCOM_LOG_SEARCH_BAR(appdata.search_bar),
             appdata.log_model);
@@ -660,7 +741,7 @@ int main( int argc, char* argv[] )
              G_OBJECT(refresh_button),
               "clicked",
               G_CALLBACK(refresh),
-              appdata.log_model);
+              &appdata);
     hildon_app_menu_append (menu, GTK_BUTTON (refresh_button));
     gtk_widget_show(refresh_button);
 
@@ -675,22 +756,22 @@ int main( int argc, char* argv[] )
 
     /*setup the filters for the app menu*/
     all_button = hildon_gtk_radio_button_new (HILDON_SIZE_AUTO, NULL);
-    gtk_button_set_label (GTK_BUTTON (all_button), "All Calls");
+    gtk_button_set_label (GTK_BUTTON (all_button), "All");
     g_signal_connect(
               G_OBJECT(all_button),
               "clicked",
-              G_CALLBACK(populate_calls),
-              appdata.log_model);
+              G_CALLBACK(all_call_directions),
+              &appdata);
     hildon_app_menu_add_filter (menu, GTK_BUTTON (all_button));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (all_button), FALSE);
 
     dialed_button = hildon_gtk_radio_button_new_from_widget (HILDON_SIZE_AUTO, GTK_RADIO_BUTTON(all_button));
-    gtk_button_set_label (GTK_BUTTON (dialed_button), "Dialed");
+    gtk_button_set_label (GTK_BUTTON (dialed_button), "Dialled");
     g_signal_connect(
               G_OBJECT(dialed_button),
               "clicked",
               G_CALLBACK(dialed_calls),
-              appdata.log_model);
+              &appdata);
     hildon_app_menu_add_filter (menu, GTK_BUTTON (dialed_button));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (dialed_button), FALSE);
 
@@ -700,7 +781,7 @@ int main( int argc, char* argv[] )
               G_OBJECT(recieved_button),
               "clicked",
               G_CALLBACK(recieved_calls),
-              appdata.log_model);
+              &appdata);
     hildon_app_menu_add_filter (menu, GTK_BUTTON (recieved_button));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (recieved_button), FALSE);
 
@@ -710,19 +791,19 @@ int main( int argc, char* argv[] )
               G_OBJECT(missed_button),
               "clicked",
               G_CALLBACK(missed_calls),
-              appdata.log_model);
+              &appdata);
     hildon_app_menu_add_filter (menu, GTK_BUTTON (missed_button));
     gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (missed_button), FALSE);
 
 
-    /*voip_button = gtk_button_new_with_label("VoIP Calls");
+    call_type_button = gtk_button_new_with_label("Call Type");
     g_signal_connect(
-              G_OBJECT(voip_button),
+              G_OBJECT(call_type_button),
               "clicked",
-              G_CALLBACK(voip_calls),
-              appdata.log_model);
-    hildon_app_menu_append (menu, GTK_BUTTON (voip_button));
-    gtk_widget_show(voip_button);*/
+              G_CALLBACK(call_type_dialog),
+              &appdata);
+    hildon_app_menu_append (menu, GTK_BUTTON (call_type_button));
+    gtk_widget_show(call_type_button);
 
     gtk_widget_show_all (GTK_WIDGET (menu));
     hildon_window_set_app_menu (HILDON_WINDOW (appdata.mainWindow), menu);
